@@ -10,7 +10,7 @@ use base 'Perl::Critic::Policy';
 
 use Readonly;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 Readonly::Scalar my $DESC => q{Use of "Dumper" is not allowed.};
 Readonly::Scalar my $EXPL => q{Use "Dump" method of MainObject instead};
@@ -42,11 +42,17 @@ Perl::Critic::Policy::OTRS::ProhibitDumper - Check module for use of "Dumper"
 
 =head1 VERSION
 
-version 0.08
+version 0.09
+
+=head1 METHODS
+
+=head2 supported_parameters
+
+There are no supported parameters.
 
 =head1 AUTHOR
 
-Renee Baecker <module@renee-baecker.de>
+Renee Baecker <info@perl-services.de>
 
 =head1 COPYRIGHT AND LICENSE
 
