@@ -10,7 +10,7 @@ use base 'Perl::Critic::Policy';
 
 use Readonly;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 Readonly::Scalar my $DESC => q{Use of low precedence operators is not allowed};
 Readonly::Scalar my $EXPL => q{Replace low precedence operators with the high precedence substitutes};
@@ -47,11 +47,17 @@ Perl::Critic::Policy::OTRS::ProhibitLowPrecedenceOps - Do not use "not", "and" a
 
 =head1 VERSION
 
-version 0.08
+version 0.09
+
+=head1 METHODS
+
+=head2 supported_parameters
+
+There are no supported parameters.
 
 =head1 AUTHOR
 
-Renee Baecker <module@renee-baecker.de>
+Renee Baecker <info@perl-services.de>
 
 =head1 COPYRIGHT AND LICENSE
 
